#ifndef _YYERROR_H
#define _YYERROR_H

#include <string>

void yyerror(const std::string &s);

#endif // _YYERROR_H
